@@ -342,8 +342,7 @@ class Band:
         for band in projected_dict:
             band_df = pd.DataFrame()
             for element in elements:
-                element_index = np.where(element_list == element)[0]
-                # element_index = np.where(np.isin(element, element_list))[0]
+                element_index = np.where(np.isin(element, element_list))[0]
                 nb_atoms = len(element_index)
                 df = pd.concat(
                     [projected_dict[band][i] for i in element_index],
